@@ -9,7 +9,7 @@
 ;; Created: 14 Nov 2001
 ;; Version: 1.0b
 ;; Keywords: maxima
-;; $Id: imaxima.lisp,v 1.8 2011/01/05 22:49:31 riotorto Exp $
+;; $Id: imaxima.lisp,v 1.8 2011-01-05 22:49:31 riotorto Exp $
 ;;
 ;; This program is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU General Public License as
@@ -672,7 +672,7 @@ nor Gnuplot is not recognized by maxima"))))
     (setq res (apply (symbol-function '$draw)
 		     (append
 		      `(
-			((mequal simp) $terminal $eps)
+			((mequal simp) $terminal $eps_color)
                         ((mequal simp) $dimensions
                                        ((mlist simp)
                                         ;; convert points to 1/100 of cm
