@@ -1217,25 +1217,36 @@ relational knowledge is contained in the default context GLOBAL.")
 		    (if (eq ans 'numer) (setq ans 'symbol)))
 		   (t (return nil)))))))
 
+(mapcar #'(lambda (s) (putprop (first s) (second s) 'sign-function))
+	(list
+	 (list 'mtimes 'sign-mtimes)
+	 (list 'mplus 'sign-mplus)
+	 (list 'mexpt 'sign-mexpt)
+	 (list '%log 'sign-log)
+	 (list 'mabs 'sign-mabs)
+	 (list '$min #'(lambda (x) (sign-minmax (caar x) (cdr x))))
+	 (list '$max #'(lambda (x) (sign-minmax (caar x) (cdr x))))
+	 (list '%csc #'(lambda (x) (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x))))))
+	 (list '%csch #'(lambda (x) (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x))))))
+
+	 (list '%signum #'(lambda (x) (sign (cadr x))))
+	 (list '%erf #'(lambda (x) (sign (cadr x))))
+	 (list '$li #'(lambda (x) 
+			(let ((z (first (margs x))) (n (cadadr x)))
+			  (if (and (mnump n) (eq t (mgrp z 0)) (eq t (mgrp 1 z))) (sign z) (sign-any x)))))))
 (defmfun sign (x)
   (cond ((mnump x) (setq sign (rgrp x 0) minus nil odds nil evens nil))
-	((and *complexsign* (atom x) (eq x '$%i))
+	((and *complexsign* (symbolp x) (eq x '$%i))
 	 ;; In Complex Mode the sign of %i is $imaginary.
 	 (setq sign '$imaginary))
-	((atom x) (if (eq x '$%i) (imag-err x)) (sign-any x))
-	((eq (caar x) 'mtimes) (sign-mtimes x))
-	((eq (caar x) 'mplus) (sign-mplus x))
-	((eq (caar x) 'mexpt) (sign-mexpt x))
-        ((eq (caar x) '%log) (sign-log x))
-	((eq (caar x) 'mabs) (sign-mabs x))
-	((member (caar x) '($min $max) :test #'eq) (sign-minmax (caar x) (cdr x)))
-	((member (caar x) '(%csc %csch) :test #'eq)
-	 (sign (inv* (cons (ncons (zl-get (caar x) 'recip)) (cdr x)))))
+	((symbolp x) (if (eq x '$%i) (imag-err x)) (sign-any x))
+	((and (consp x) (symbolp (caar x)) (not (specrepp x)) (get (caar x) 'sign-function))
+	 (funcall (get (caar x) 'sign-function) x))
+	((and (consp x) (not (specrepp x)) ($subvarp (mop x)) (get (mop (mop x)) 'sign-function))
+	 (funcall (get (mop (mop x)) 'sign-function) x))
 	((specrepp x) (sign (specdisrep x)))
 	((kindp (caar x) '$posfun) (sign-posfun x))
-	((or (member (caar x) '(%signum %erf) :test #'eq)
-	     (and (kindp (caar x) '$oddfun) (kindp (caar x) '$increasing)))
-	 (sign-oddinc x))
+	((and (kindp (caar x) '$oddfun) (kindp (caar x) '$increasing)) (sign-oddinc x))
 	(t (sign-any x))))
 
 (defun sign-any (x)
@@ -1328,7 +1339,7 @@ relational knowledge is contained in the default context GLOBAL.")
 (defun signdiff-special (xlhs xrhs)
   ;; xlhs may be a constant
   (let ((sgn nil))
-    (when (or (and (numberp xrhs) (minusp xrhs)
+    (when (or (and (realp xrhs) (minusp xrhs)
 		   (not (atom xlhs)) (eq (sign* xlhs) '$pos))
 					; e.g. sign(a^3+%pi-1) where a>0
 	      (and (mexptp xlhs)
@@ -1748,7 +1759,7 @@ relational knowledge is contained in the default context GLOBAL.")
           ind))
         ;; Properties not related to the assume database.
         ((and (member ind opers) (get e ind)))
-        ((and (member ind '($evfun $evflag $bindtest $special $nonarray))
+        ((and (member ind '($evfun $evflag $bindtest $nonarray))
               (get e (stripdollar ind))))
         ((and (eq ind '$noun)
               (get e (stripdollar ind))
