@@ -131,10 +131,10 @@
     (t (setq x  (cdr x))
        (do () ((null x) l) (setq l (string1 (car x) l) x (cdr x))))))
 
-
 (defun msize (x l r lop rop)
   (setq x (nformat x))
   (cond ((atom x) (if fortranp (msz (makestring x) l r) (msize-atom x l r)))
+        ((and (atom (car x)) (setq x (cons '(mprogn) x)) nil))
 	((or (<= (lbp (caar x)) (rbp lop)) (> (lbp rop) (rbp (caar x))))
 	 (msize-paren x l r))
 	((member 'array (cdar x) :test #'eq) (msize-array x l r))
@@ -145,26 +145,29 @@
 (defun msize-atom (x l r)
   (prog (y)
      (cond ((numberp x) (setq y (exploden x)))
-	   ((stringp x)
-        (setq y (coerce x 'list))
-	    (do ((l y (cdr l))) ((null l))
-	      (cond
-            ((member (car l) '(#\" #\\) :test #'equal)
-             (rplacd l (cons (car l) (cdr l)))
-             (rplaca l #\\)
-             (setq l (cdr l)))))
-        (setq y (cons #\" (nconc y (list #\")))))
-	   ((and (setq y (safe-get x 'reversealias))
-		 (not (and (member x $aliases :test #'eq) (get x 'noun))))
-	    (setq y (exploden (stripdollar y))))
-	   ((setq y (rassoc x aliaslist :test #'eq)) (return (msize (car y) l r lop rop)))
-       ((null (setq y (exploden x))))
-       ((safe-get x 'noun) (return (msize-atom (get x 'noun) l r)))
-	   ((char= #\$ (car y)) (setq y (slash (cdr y))))
-       (t (setq y (cons #\? (slash y)))))
+           ((stringp x)
+            (setq y (coerce x 'list))
+            (do ((l y (cdr l))) ((null l))
+              (cond ((member (car l) '(#\" #\\ ) :test #'equal)
+                     (rplacd l (cons (car l) (cdr l)))
+                     (rplaca l #\\ )
+                     (setq l (cdr l)))))
+            (setq y (cons #\" (nconc y (list #\")))))
+           ((and (setq y (safe-get x 'reversealias))
+                 (not (and (member x $aliases :test #'eq) (get x 'noun))))
+            (setq y (exploden (stripdollar y))))
+           ((setq y (rassoc x aliaslist :test #'eq))
+            (return (msize (car y) l r lop rop)))
+           ((null (setq y (exploden x))))
+           ((safe-get x 'noun) (return (msize-atom (get x 'noun) l r)))
+           ((char= #\$ (car y)) (setq y (slash (cdr y))))
+           ((member (marray-type x) '(array hash-table $functional))
+            (return (msize-array-object x l r)))
+           (t (setq y (cons #\? (slash y)))))
      (return (msz y l r))))
 
-(defun msz (x l r) (setq x (nreconc l (nconc x r))) (cons (length x) x))
+(defun msz (x l r)
+  (setq x (nreconc l (nconc x r))) (cons (length x) x))
 
 (defun slash (x)
   (do ((l (cdr x) (cdr l))) ((null l))
@@ -268,6 +271,8 @@
   (msz (mapcar #'(lambda (l) (getcharn l 1)) (fpformat x)) l r))
 
 (defprop mprogn msize-matchfix grind)
+(defprop mprogn ((#\( ) #\) ) strsym)
+
 (defprop mlist msize-matchfix grind)
 
 (defprop mqapply msz-mqapply grind)
