@@ -14,8 +14,14 @@
 
 (macsyma-module system)
 
+(defmvar $showtime nil
+  "When T, the computation time is printed with each output expression.")
+
 ;;; Standard Kinds of Input Prompts
 
+(defmvar $prompt '_
+  "Prompt symbol of the demo function, playback, and the Maxima break loop.")
+
 (defvar *prompt-prefix* "")
 (defvar *prompt-suffix* "")
 (defvar *general-display-prefix* "")
@@ -28,14 +34,20 @@
   ;; a FUNARG as the prompt. -gjc
   (declare (special *display-labels-p*))
   (if *display-labels-p*
-    (format nil "~A(~A~D) ~A"
-	    *prompt-prefix* (print-invert-case (stripdollar $inchar))
-	    $linenum *prompt-suffix*)
+      (let ((*print-circle* nil))
+	(format nil "~A(~A~D) ~A"
+		*prompt-prefix*
+		(print-invert-case (stripdollar $inchar))
+		$linenum
+		*prompt-suffix*))
     ""))
 
 (defun break-prompt ()
-  (declare (special $prompt))
-  (stripdollar $prompt))
+  (let ((*print-circle* nil))
+    (format nil "~A~A~A"
+	    *prompt-prefix*
+	    (print-invert-case (stripdollar $prompt))
+	    *prompt-suffix*)))
 
 ;; there is absoletely no need to catch errors here, because
 ;; they are caught by the macsyma-listener window process on
@@ -110,7 +122,10 @@
 		 batch-or-demo-flag)
   (declare (special *socket-connection*))
   (if (eql batch-or-demo-flag :demo)
-      (format t (intl:gettext "~% At the _ prompt, type ';' and <enter> to get next demonstration.~&")))
+      (format t
+        (intl:gettext
+          "~%At the '~A' prompt, type ';' and <enter> to get next demonstration.~&")
+        (print-invert-case (stripdollar $prompt))))
   (catch 'abort-demo
     (do ((r)
 	 (time-before)
@@ -192,7 +207,7 @@
 	(when $showtime	;; we don't distinguish showtime:all?? /RJF
 	  (format t (intl:gettext "Evaluation took ~,4F seconds (~,4F elapsed)")
 		  time-used etime-used )
-	  #+(or gcl ecl)
+	  #+(or gcl ecl openmcl)
 	  (format t "~%")
 	  #+(or cmu scl sbcl clisp)
 	  (let ((total-bytes (- area-after area-before)))
@@ -216,15 +231,20 @@
 	(if (eq (caar r) 'displayinput)
 	    (displa `((mlable) ,d-tag ,$%))) ;; consistently misspelling label.
 	(when (eq batch-or-demo-flag ':demo)
-	  (mtell "~A_~A" *prompt-prefix* *prompt-suffix*)
+          (princ (break-prompt))
+          (force-output)
 	  (let (quitting)
 	    (do ((char)) (nil)
 	      ;;those are common lisp characters you're reading here
 	      (case (setq char (read-char *terminal-io*))
-		((#\page)
-		 (terpri *standard-output*)
-		 (princ "_" *standard-output*))
-		((#\?) (mtell (intl:gettext "  Pausing. Type a ';' and <enter> to continue demo.~%")))
+                ((#\page)
+                 (fresh-line)
+                 (princ (break-prompt))
+                 (force-output))
+                ((#\?)
+                 (format t
+                   (intl:gettext
+                     "  Pausing. Type a ';' and <enter> to continue demo.~%")))
 		((#\space #\; #\n #\e #\x #\t))
 		((#\newline )
 		 (if quitting (throw 'abort-demo nil) (return nil)))
@@ -285,7 +305,8 @@
 	 (princ *prompt-suffix*)
 	 (mterpri)))
   (let ((res (mread-noprompt *query-io* nil)))
-       (princ *general-display-prefix*) res))
+    (princ *general-display-prefix*)
+    res))
 
 (defmfun $read (&rest l)
   (meval (apply #'$readonly l)))
@@ -322,11 +343,6 @@
   (continue (make-echo-stream fileobj *standard-output*)
 	    (if demo-p ':demo ':batch)))
 
-(defun filename-from-arg-list (arg-list)
-  (if (= (length arg-list) 1)
-      ($filename_merge (car arg-list))
-      ($filename_merge `((mlist),@arg-list))))
-
 (defmspec $grindef (form)
   (eval `(grindef ,@(cdr form)))
   '$done)
